@@ -187,7 +187,6 @@ class Seti():
         return ResponseCreateTransaction(self.send_request(data_send_money,encode_data,REVERSAL_PAYMENT_URL))
     
     # Recharger
-    
     def create_recharger(self,value:int,secret:str):
         self.is_error =False
         self.validate_value(value)
@@ -198,9 +197,7 @@ class Seti():
         CREATE_RECHARGER_URL = "create-recharger"
         encode_data = self.sign_data(data_create_recharger)
         return ResponseCreatePayment(self.send_request(data_create_recharger,encode_data,CREATE_RECHARGER_URL))
-    
     # Dispersion
-    
     def create_dispersion(self,value:int,description:str,currency:str,auth_email:str):
         self.is_error =False
         self.validate_value(value)
@@ -225,7 +222,6 @@ class Seti():
         encode_data = self.sign_data(data_create_dispersion)
         return ResponseCreateTransaction(self.send_request(data_create_dispersion,encode_data,CREATE_DISPERSION_URL))
     
-    
     # Read
     def read_payment(self,payment_id:str):
         self.is_error =False
@@ -236,7 +232,6 @@ class Seti():
         encode_data = self.sign_data(data_read_payment)
         return ResponseReadPayment(self.send_request(data_read_payment,encode_data,READ_PAYMENT_URL))
     
-    
     def read_cash(self,currency:str):
         self.is_error =False
         self.validate_currency(currency)
@@ -246,7 +241,6 @@ class Seti():
         READ_CASH_URL = "read-cash"
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadCash(self.send_request(data_read_cash,encode_data,READ_CASH_URL))
-    
 
     def read_total_cash_outs(self,currency:str):
         self.is_error =False
@@ -258,7 +252,6 @@ class Seti():
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadCashOut(self.send_request(data_read_cash,encode_data,READ_TOTAL_CASH_OUT_URL))
     
-    
     def read_transactions(self):
         self.is_error =False
         data_read_cash = {}
@@ -266,9 +259,30 @@ class Seti():
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadTransactions(self.send_request(data_read_cash,encode_data,READ_TRANSACTIONS_URL))
     
+    def validate_exist_user(self,email:str):
+        self.is_error =False
+        user_data = {
+            "email": email
+        }
+        VALIDATE_USERS_EXIST = "validate-user"
+        encode_data = self.sign_data(user_data)
+        return ResponseReadCashOut(self.send_request(user_data,encode_data,VALIDATE_USERS_EXIST))
+    
+    def create_user(self,email:str,name:str,phone:str,iso_code:str):
+        self.is_error =False
+        self.validate_email(email)
+        self.validate_currency(iso_code)
+        user_data = {
+            "email": email,
+            "name": name,
+            "phone": phone,
+            "isoCode": iso_code
+        }
+        VALIDATE_USERS_EXIST = "create-user"
+        encode_data = self.sign_data(user_data)
+        return ResponseReadCashOut(self.send_request(user_data,encode_data,VALIDATE_USERS_EXIST))
     
 
 
 
 
-
