@@ -63,7 +63,8 @@ class ResponseReadPayment(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = ResponseReadPaymentData(data['data'])
-
+        else:
+            self.data = ResponseReadPaymentData({})
 
 # Read Cash
 
@@ -83,7 +84,8 @@ class ResponseReadCash(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = ResponseReadPaymentData(data['data'])
-        
+        else:
+            self.data = ResponseReadPaymentData({})
         
 # Read total CashOUts
 
@@ -103,7 +105,8 @@ class ResponseReadCashOut(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = ResponseReadCashOutData(data['data'])
-
+        else:
+            self.data = ResponseReadPaymentData({})
 
 # Read transactions
 
@@ -145,8 +148,9 @@ class ResponseReadTransactions(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = ResponseReadTransactionsData(data['data'])
-   
-   
+        else:
+            self.data = ResponseReadPaymentData({})
+
 # Read Wallet
 
 class WalletData:
@@ -170,8 +174,8 @@ class ResponseReadWallet(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = WalletData(data['data'])
-   
-   
+        else:
+            self.data = ResponseReadPaymentData({})
    
    
 # Read Wallet Movements
@@ -190,4 +194,26 @@ class ResponseReadWalletsTransactions(BasicResponse):
         if data['res'] == 200:
             self.data = ResponseReadWallesMovemtsData(data['data'])
    
-   
\ No newline at end of file
+# Read Validate User Exist
+class ExistUser:
+    def __init__(self,data:dict):
+        self.exist = data['exist']
+        
+
+class ResponseValidateUser(BasicResponse):
+    data: ExistUser
+    def __init__(self,data:dict):
+        self.msg=data['msg']
+        self.res=data['res']
+        if data['res'] == 200:
+            self.data =ExistUser(data['data'])
+        else:
+            self.data = ExistUser({})
+
+# Create Users
+
+class ResponseCreateUser(BasicResponse):
+    def __init__(self,data:dict):
+        self.msg=data['msg']
+        self.res=data['res']
+        self.data = {}
